@@ -8,28 +8,26 @@
 #ifndef _LAYERSHELLINTEGRATION_P_H
 #define _LAYERSHELLINTEGRATION_P_H
 
-#include <wayland-client.h>
-
 #include "layershellqt_export.h"
+
 #include <QtWaylandClient/private/qwaylandshellintegration_p.h>
+#include <qwayland-wlr-layer-shell-unstable-v1.h>
+
+class QWaylandXdgActivationV1;
 
 namespace LayerShellQt
 {
-class QWaylandLayerShell;
 
-class LAYERSHELLQT_EXPORT QWaylandLayerShellIntegration : public QtWaylandClient::QWaylandShellIntegration
+class LAYERSHELLQT_EXPORT QWaylandLayerShellIntegration : public QtWaylandClient::QWaylandShellIntegrationTemplate<QWaylandLayerShellIntegration>, public QtWayland::zwlr_layer_shell_v1
 {
 public:
     QWaylandLayerShellIntegration();
     ~QWaylandLayerShellIntegration() override;
 
-    bool initialize(QtWaylandClient::QWaylandDisplay *display) override;
+    QWaylandXdgActivationV1 *activation() const { return m_xdgActivation.data(); }
     QtWaylandClient::QWaylandShellSurface *createShellSurface(QtWaylandClient::QWaylandWindow *window) override;
-
 private:
-    static void registryLayer(void *data, struct wl_registry *registry, uint32_t id, const QString &interface, uint32_t version);
-
-    QScopedPointer<QWaylandLayerShell> m_layerShell;
+    QScopedPointer<QWaylandXdgActivationV1> m_xdgActivation;
 };
 
 }
